@@ -3,6 +3,7 @@ import pickle as pk
 from datetime import datetime
 import pandas as pd
 from fair_dynamic_rec.core.util.utils import get_dict_key_from_value
+from tqdm import tqdm
 
 class DataCmd:
     """
@@ -43,7 +44,7 @@ class DataCmd:
         data = np.array(np.zeros((1, 1)))
         user_index, item_index = 0, 0
         with open(file_path) as f:
-            for instance in f:
+            for instance in tqdm(f):
                 instance_separated = instance.strip().split(delimiter)
                 userid = instance_separated[0]
                 itemid = instance_separated[1]
@@ -65,6 +66,27 @@ class DataCmd:
 
                 data[self.userid_mapped_data[userid], self.itemid_mapped_data[itemid]] = rating
 
+        return data
+    def read_rating_text_file_given_size(self, file_path, delimiter, n_rows, n_cols):
+        data = np.array(np.zeros((n_rows, n_cols)))
+        user_index, item_index = 0, 0
+        with open(file_path) as f:
+            for instance in tqdm(f):
+                instance_separated = instance.strip().split(delimiter)
+                userid = instance_separated[0]
+                itemid = instance_separated[1]
+                rating = instance_separated[2]
+
+                # map userid and itemid, and update the dictionary
+                if userid not in self.userid_mapped_data.keys():
+                    self.userid_mapped_data[userid] = user_index
+                    user_index += 1
+                if itemid not in self.itemid_mapped_data.keys():
+                    self.itemid_mapped_data[itemid] = item_index
+                    item_index += 1
+
+                data[self.userid_mapped_data[userid], self.itemid_mapped_data[itemid]] = rating
+
         return data
     def read_train_test_text_file(self, train_path, test_path, train_delimiter, test_delimiter):
         train_df = pd.read_csv(train_path, names=['userid', 'itemid', 'rating'], sep='\t')
@@ -211,7 +233,11 @@ class DataCmd:
     def load_data_from_text_file(self, config):
         self.ratings, self.train_data, self.test_data, self.user_data, self.item_data, self.supplier_data = None, None, None, None, None, None
         if self.rating_file_path is not None:
-            self.ratings = self.read_rating_text_file(self.rating_file_path, config.get_rating_data_delimiter())
+            n_rows, n_cols = config.get_rating_data_size()
+            if n_rows is not None and n_cols is not None:
+                self.ratings = self.read_rating_text_file_given_size(self.rating_file_path, config.get_rating_data_delimiter(), n_rows, n_cols)
+            else:
+                self.ratings = self.read_rating_text_file(self.rating_file_path, config.get_rating_data_delimiter())
         if config.get_splitter_model() == 'giventraintest':
             # self.train_data = self.read_rating_text_file(self.train_file_path, config.get_train_data_delimiter())
             # self.test_data = self.read_test_text_file(self.test_file_path, config.get_test_data_delimiter())
@@ -278,7 +304,7 @@ class DataCmd:
         save_data, train_file_name, test_file_name = config.get_save_txt_data_info()
         if save_data:
             f = open(config.get_data_path() / train_file_name, "w")
-            for u in range(self.train_data.shape[0]):
+            for u in tqdm(range(self.train_data.shape[0])):
                 # items = np.asarray(np.where(self.train_data[u] == 1))[0]
                 items = np.asarray(np.where(self.train_data[u] > 0))[0]
                 for j in range(len(items)):
@@ -286,7 +312,7 @@ class DataCmd:
             f.close()
 
             f = open(config.get_data_path() / test_file_name, "w")
-            for u in range(self.test_data.shape[0]):
+            for u in tqdm(range(self.test_data.shape[0])):
                 items = np.asarray(np.where(self.test_data[u] > 0))[0]
                 # items = np.asarray(np.where(self.test_data[u] == 1))[0]
                 for j in range(len(items)):
